@@ -3,6 +3,7 @@ import os
 import datetime
 import bisect
 import openpyxl
+import pathlib
 import xml.etree.ElementTree
 import numpy as np
 from typing import List, Union, Tuple
@@ -28,7 +29,7 @@ _simple_re = re.compile(
 )
 # regex for matching acaml file extensions (upper or lower case)
 _acaml_re = re.compile(
-    '.+\.acam(_|l)$',
+    '\.acam(_|l)$',
     re.IGNORECASE,
 )
 # sequence acaml re
@@ -268,14 +269,23 @@ class HPLCSampleInfo(object):
         }
 
     @classmethod
-    def get_values_from_acaml(cls, acaml: Union[str, xml.etree.ElementTree.ElementTree]) -> dict:
+    def get_values_from_acaml(cls,
+                              acaml: Union[
+                                  str,
+                                  pathlib.Path,
+                                  xml.etree.ElementTree.ElementTree,
+                              ]
+                              ) -> dict:
         """
         Gets relevant values from an acaml file. (use sequence.acam_ in the desired .D folder)
 
         :param acaml: path to acaml file or parsed element tree root
         :return: dictionary of values of interest
         """
-        if type(acaml) is str:  # assume target path if string
+        # if provided with a path, create element tree
+        if isinstance(acaml, xml.etree.ElementTree.ElementTree) is False:
+            if type(acaml) is str:  # type convert to path if raw string
+                acaml = pathlib.Path(acaml)
             if os.path.isdir(acaml):  # not a acaml file
                 seq_files = [filename for filename in os.listdir(acaml) if _seq_acaml_re.match(filename) is not None]
                 if len(seq_files) != 1:
@@ -288,7 +298,7 @@ class HPLCSampleInfo(object):
                     seq_files[0]
                 )
             else:
-                if _acaml_re.match(acaml) is None:
+                if _acaml_re.search(acaml) is None:
                     # todo consider trying to parse anyway
                     raise ValueError(f'The file "{acaml}" does not have a valid extension')
             acaml = xml.etree.ElementTree.parse(
@@ -470,14 +480,16 @@ class DADSpectrum(AgilentCSDAD2):
         )
 
     @classmethod
-    def create_from_D_file(cls, file_path: str) -> "DADSpectrum":
+    def create_from_D_file(cls, file_path: Union[pathlib.Path, str]) -> "DADSpectrum":
         """
         Creates a DADSpectrum instance from an Agilent .D file
 
         :param file_path: path to .D sample file
         :return: interpreted .D file with metadata and loaded UV data
         """
-        if file_path.endswith('.D') is False or os.path.isdir(file_path) is False:
+        if type(file_path) is str:
+            file_path = pathlib.Path(file_path)
+        if file_path.suffix != '.D' or os.path.isdir(file_path) is False:
             raise ValueError(f'The file path "{file_path}" does not appear to be a valid Agilent sample directory')
         uv_files = [filename for filename in os.listdir(file_path) if filename.endswith('.UV')]
         # todo catch if multiple UV files (does this happen?)
@@ -711,14 +723,16 @@ class HPLCSample(HPLCSampleInfo):
         self.directory = directory
 
     @classmethod
-    def create_from_D_file(cls, file_path: str) -> "HPLCSample":
+    def create_from_D_file(cls, file_path: Union[pathlib.Path, str]) -> "HPLCSample":
         """
         Creates an HPLCSample instance from a .D file.
 
         :param file_path: file path to Agilent .D folder
         :return: instantiated HPLCSample with loaded data
         """
-        if file_path.endswith('.D') is False or os.path.isdir(file_path) is False:
+        if isinstance(file_path, pathlib.Path) is False:
+            file_path = pathlib.Path(file_path)
+        if file_path.suffix != '.D' is False or os.path.isdir(file_path) is False:
             raise ValueError(f'The file path "{file_path}" does not appear to be a valid Agilent sample directory')
         sample_info_values = HPLCSampleInfo.get_values_from_acaml(file_path)
         spectrum = DADSpectrum.create_from_D_file(file_path)
